@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use base qw/Import::Export/;
 
@@ -25,7 +25,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -35,7 +35,7 @@ Version 0.07
 
 	const my $scalar => 'Hello World';
 	const my @array => qw/welcome to paradise/;
-	const my %hash => ( one => 1, two => 2, three => 3 );
+	const my %hash => ( one => 1, two => [ ... ], three => { ... }, four => sub { } );
 
 
 =head1 EXPORTS
